@@ -74,7 +74,77 @@ static char *vendors[] =
 
 static char *models[] =
 {
-        "K6 (166 - 266)", "K6",
+#ifdef use_regexp
+        "K6 \\(166 - 266\\)", "K6",
+        "AMD-K6tm w/ mul", "K6 (MMX)",
+        "K6-2 \\(PR233 - PR333\\)", "K6-2",
+        "AMD-K6\\(tm\\) 3D", "K6-3 (3DNow)",
+        "AMD-K6\\(tm\\) 3D+", "K6-3 (3DNow+)",
+	"AMD-K6\\(tm\\)-III", "K6-3 (3DNowExt)",
+	"AMD-K7\\(tm\\)", "K7",
+	"Athlon", "Athlon",
+	"AMD Athlon\\(tm\\) processor", "Athlon",
+        "AMD Athlon\\(tm\\) Processor", "Athlon",
+        "AMD Athlon\\(TM\\) XP", "Athlon XP",
+        "AMD Athlon\\(tm\\) XP [0-9]{4}+", "Athlon XP",
+        "AMD Athlon\\(TM\\) MP", "Athlon MP",
+	"AMD Opteron\\(tm\\) Processor [0-9]{3}","Opteron",
+	"AMD Opteron 23xx \\(Gen 3 Class Opteron\\)", "Opteron Gen 3",
+	"AMD Sempron\\(tm\\)   [0-9]{4}+", "Sempron",
+	"AMD Athlon\\(tm\\) 64 Processor [0-9]{4}+", "x86_64",
+	"AMD Athlon\\(tm\\) 64 X2 Dual Core Processor [0-9]{4}+", "x86_64",
+	"AMD Athlon\\(tm\\) II X4 [0-9]{3} Processor", "Athlon(tm) II",
+	"AMD Phenom\\(tm\\) II X6 1055T Processor", "Phenom II",
+	"Intel\\(R\\) Xeon\\(TM\\) CPU [0-9]\\.[0-9]{2}GHz", "Xeon",
+	"AMD A6-6310 APU with AMD Radeon R4 Graphics", "A6-6310 with Radeon R4",
+	"AMD FX\\(tm\\)-4300 Quad-Core Processor", "x86_64 FX",
+        "Am5x86", "5x86",
+        "C6", "C6",
+	"C6-2", "C6-2",
+        "6x86", "6x86",
+        "6x86MX", "6x86MX",
+        "Geode\\(TM\\) Integrated Processor by National Semi", "Geode by Nat. Sem.",
+	"Geode\\(TM\\) Integrated Processor by AMD PCS", "Geode by AMD PCS",
+        "Pentium 75+", "Pentium",
+        "Pentium 75 - 200", "Pentium",
+        "Pentium MMX", "Pentium MMX",
+        "Mobile Pentium MMX", "Mobile Pentium MMX",
+        "Pentium Pro", "Pentium Pro",
+        "Pentium II \\(Klamath\\)", "Pentium II (Klamath)",
+        "Pentium II \\(Deschutes\\)", "Pentium II (Deschutes)",
+        "Pentium III \\(Katmai\\)", "Pentium III (Katmai)",
+	"Pentium III \\(Coppermine\\)", "Pentium III (Coppermine)",
+	"Intel\\(R\\) Pentium\\(R\\) CPU G2020T @ [0-9]\\.[0-9]{2}GHz", "Pentium",
+	"Intel\\(R\\) Pentium\\(R\\) 4 CPU [0-9]\\.[0-9]{2}GHz", "Pentium 4",
+	"Intel\\(R\\) Pentium\\(R\\) M processor", "Pentium M",
+	"Intel\\(R\\) Pentium\\(R\\) M processor [0-9]{4}MHz", "Pentium M",
+	"Intel\\(R\\) XEON\\(TM\\) CPU [0-9]\\.[0-9]{2}GHz", "Xeon",
+	"Intel\\(R\\) Xeon\\(R\\) CPU           E5345  @ [0-9]\\.[0-9]{2}GHz","Xeon",
+	"Intel\\(R\\) Xeon\\(R\\) CPU           L5420  @ [0-9]\\.[0-9]{2}GHz","Xeon",
+        "Celeron \\(Coppermine\\)", "Celeron (Coppermine)",
+        "Celeron \\(Mendocino\\)", "Celeron (Mendocino)",
+        "Celeron \\(Covington\\)", "Celeron (Covington)",
+	"Intel\\(R\\) Celeron\\(R\\) CPU [0-9]\\.[0-9]{2}GHz", "Celeron",
+	"Intel\\(R\\) Celeron\\(R\\) M processor         [0-9]\\.[0-9]{2}GHz", "Celeron M",
+	"Mobile Intel\\(R\\) Celeron\\(TM\\) CPU          [0-9]{3}MHz", "Mobile Celeron",
+	"Mobile Intel\\(R\\) Pentium\\(R\\) 4     CPU [0-9]\\.[0-9]{2}GHz", "Mobile Pentium 4",
+	"Intel\\(R\\) Core\\(TM\\) Solo CPU     U1400  @ [0-9]\\.[0-9]{2}GHz", "Core Solo",
+	"Intel\\(R\\) Core\\(TM\\) i7-4600M CPU @ [0-9]\\.[0-9]{2}GHz", "Core i7",
+	"Intel\\(R\\) Core\\(TM\\)2 CPU          6600  @ [0-9]\\.[0-9]{2}GHz", "Core 2",
+	"Intel\\(R\\) Core\\(TM\\)2 Duo CPU     E6750  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Duo",
+	"Intel\\(R\\) Core\\(TM\\)2 Duo CPU     P8600  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Duo",
+	"Intel\\(R\\) Core\\(TM\\)2 Duo CPU     E7400  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Duo",
+	"Intel\\(R\\) Core\\(TM\\)2 Duo CPU     E8400  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Duo",
+	"Intel\\(R\\) Core\\(TM\\)2 Quad CPU    Q6600  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Quad",
+	"Intel\\(R\\) Core\\(TM\\)2 Quad CPU    Q9550  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Quad",
+	"Intel\\(R\\) Core\\(TM\\) i5-4210U CPU @ [0-9]\\.[0-9]{2}GHz", "Core i5",
+	"Intel\\(R\\) Core\\(TM\\) i5-6200U CPU @ [0-9]\\.[0-9]{2}GHz", "Core i5",
+	"Intel\\(R\\) Core\\(TM\\) i5-6600 CPU @ [0-9]\\.[0-9]{2}GHz", "Core i5",
+	"Intel\\(R\\) Core\\(TM\\) i7-6600U CPU @ [0-9]\\.[0-9]{2}GHz", "Core i7",
+	"Genuine Intel\\(R\\) CPU            2140  @ [0-9]\\.[0-9]{2}GHz", "Pentium 4",
+	"Intel\\(R\\) Atom\\(TM\\) CPU N450   @ [0-9]\\.[0-9]{2}GHz", "Atom",
+#else
+	"K6 (166 - 266)", "K6",
         "AMD-K6tm w/ mul", "K6 (MMX)",
         "K6-2 (PR233 - PR333)", "K6-2",
         "AMD-K6(tm) 3D", "K6-3 (3DNow)",
@@ -162,6 +232,7 @@ static char *models[] =
 	"Intel(R) Core(TM) i7-6600U CPU @ 2.60GHz", "Core i7",
 	"Genuine Intel(R) CPU            2140  @ 1.60GHz", "Pentium 4",
 	"Intel(R) Atom(TM) CPU N450   @ 1.66GHz", "Atom",
+#endif
         NULL, NULL
 };
 
@@ -200,15 +271,22 @@ void GetHardwareInfo(int fd, struct hw_stat *hw)
 					i += 2;
 				}
 			}
-
-			if (strncmp(temp_string, "model", strlen("model")) == 0) 
+#ifdef use_regexp
+			if (strncmp(temp_string, "model name", strlen("model name")) == 0)
+#else
+			if (strncmp(temp_string, "model", strlen("model")) == 0)
+#endif
 			{
 				int i = 0;
 				int found = 0;
 		
 				while ((models[i] != NULL)&&(!found))
 				{
+#ifdef use_regexp
+					if (regstrcmp(temp_string2, models[i], strlen(models[i])) == 0)
+#else
 					if (strncmp(temp_string2, models[i], strlen(models[i])) == 0)
+#endif
 					{
 						strcpy(model, models[++i]);
 						found=1;
